/***
  Copyright (c) 2017 CommonsWare, LLC
  Licensed under the Apache License, Version 2.0 (the "License"); you may not
  use this file except in compliance with the License. You may obtain	a copy
  of the License at http://www.apache.org/licenses/LICENSE-2.0. Unless required
  by applicable law or agreed to in writing, software distributed under the
  License is distributed on an "AS IS" BASIS,	WITHOUT	WARRANTIES OR CONDITIONS
  OF ANY KIND, either express or implied. See the License for the specific
  language governing permissions and limitations under the License.
  
  Covered in detail in the book _The Busy Coder's Guide to Android Development_
    https://commonsware.com/Android
*/

package com.commonsware.android.exception.recoverable;

import android.app.Activity;
import android.app.PendingIntent;
import android.app.RecoverableSecurityException;
import android.app.RemoteAction;
import android.content.Intent;
import android.graphics.drawable.Icon;
import android.net.Uri;
import android.os.Bundle;
import android.preference.PreferenceDataStore;
import android.view.View;
import android.widget.Toast;
import com.commonsware.cwac.crossport.design.widget.Snackbar;

public class MainActivity extends Activity {
  @Override
  public void onCreate(Bundle icicle) {
    super.onCreate(icicle);
    setContentView(R.layout.main);
  }

  public void notify(View view) {
    try {
      goBoom();
    }
    catch (RecoverableSecurityException e) {
      e.showAsNotification(this);
    }
  }

  public void dialog(View view) {
    try {
      goBoom();
    }
    catch (RecoverableSecurityException e) {
      e.showAsDialog(this);
    }
  }

  public void snackbar(View view) {
    try {
      goBoom();
    }
    catch (RecoverableSecurityException e) {
      final RemoteAction action=e.getUserAction();

      Snackbar
        .make(view, e.getUserMessage(), Snackbar.LENGTH_INDEFINITE)
        .setAction(action.getTitle(), new View.OnClickListener() {
          @Override
          public void onClick(View view) {
            try {
              action.getActionIntent().send();
            }
            catch (PendingIntent.CanceledException e1) {
              Toast
                .makeText(MainActivity.this, R.string.msg_um, Toast.LENGTH_LONG)
                .show();
            }
          }
        })
        .show();
    }
  }

  private void goBoom() {
    throw new RecoverableSecurityException(new Throwable(),
      getString(R.string.msg_user), buildRemoteAction());
  }

  private RemoteAction buildRemoteAction() {
    Icon icon=Icon.createWithResource(this, R.drawable.ic_launcher);
    String title=getString(R.string.action_title);
    String desc=getString(R.string.action_desc);

    return(new RemoteAction(icon, title, desc, buildPendingIntent()));
  }

  private PendingIntent buildPendingIntent() {
    Intent i=new Intent(this, RecoveryActivity.class);

    return(PendingIntent.getActivity(this, 0, i, 0));
  }
}
